define(function(require, exports, module){
    // 定义私有业务模块变量
    var appUtils      = require("appUtils"),
        service       = require("serviceImp").getInstance(),
        global        = require("gconfig").global,
        layerUtils    = require("layerUtils"),
        validatorUtil = require("validatorUtil"),
        utils         = require('utils'),

        _pageId       = "#account_brokerInfo";

    var AGENT,
        SHOW_SETTING,
        MOBILE_NO,
        USER_ID,
        BROKER_INFO = {}, //经纪人相关信息
        BRANCH_NO,
        COMMISSION,
        INTERVAL;

    // 初始化函数
    function init(){
        AGENT         = appUtils.getSStorageInfo("agent"),
        SHOW_SETTING  = appUtils.getSStorageInfo("showsetting"),
        MOBILE_NO     = appUtils.getSStorageInfo("mobileNo"),
        USER_ID       = appUtils.getSStorageInfo("user_id"),
        getBranchByAgent(AGENT);
    }

    // 事件绑定函数
    function bindPageEvent(){

        var $btn_verify      = $(_pageId + " .btn-verify"),             // 验证码按钮
            $txt_commission  = $(_pageId + " #agent-commission"),       // 佣金输入框
            $broker_verify   = $(_pageId + " #broker-verify"),          // 验证码输入组件（含输入框）
            $next            = $(_pageId + " .btn-next-step"),          // 下一步按钮
            $commission_desc = $(_pageId + " .commission-desc");        // 佣金描述

        //在输入佣金的时候进行检测 如果佣金值不为默认佣金则提示验证码
        appUtils.bindEvent($txt_commission, function() {
            var v =$(this).val().trim();
            if(Number(v) !== utils.floatMultiOpera(COMMISSION,100)){
                $btn_verify.show();
                $broker_verify.show();
                $commission_desc.text('佣金修改后请点击“发送验证码”，并联系营销人员获取验证码,在下方填写完验证码后继续开户。');
            }else{
                $btn_verify.hide();
                $broker_verify.hide();
                $commission_desc.text('以上佣金为营业部默认佣金，如果您与营销人员约定了佣金，请修改佣金，否则将会影响您的正常开户。');
            }

        },'input');

         //检测用户输入的佣金数值
        appUtils.bindEvent($txt_commission, function() {
            var v =$(this).val().trim();
            if(!checkCommission(v)){
                $(this).val(utils.floatMultiOpera(COMMISSION,100)).trigger('input');
                return;
            }
        },'blur');





        //发送验证码给经纪人
        appUtils.bindEvent($btn_verify, function() {
            if($(this).hasClass('disabled')){
                return;
            }

            if(!checkCommission($txt_commission.val())){
                return;
            }

            sendSmsToBroker(true);
        });


        // 查阅经纪人禁止行为说明
        appUtils.bindEvent($(_pageId+" #info-desc"), function(e){
            e.preventDefault();
            appUtils.pageInit("account/brokerInfo", "account/showDigitalProtocol",{"protocolId" : "8001"});
        });

        // 下一步(继续开户)
        appUtils.bindEvent($next, function() {
            if($(this).hasClass('disabled')){
                return;
            }
            confirmCommission();

        });

    }

    function destroy(){
        service.destroy();

    }

    // 提交表单确认佣金
    function confirmCommission(){

        var broker_commission = $(_pageId + " #agent-commission").val()

        //佣金校验
        if(!checkCommission(broker_commission)){
            return;
        }

        //佣金数值未改变
        if(broker_commission == utils.floatMultiOpera(COMMISSION,100) ){
            sendSmsToBroker(false);
            return;
        }

        checkSmsCode();

    }

    // 根据经纪人编码查询营业部
    function getBranchByAgent(agent){

        var $agent_name = $(_pageId+' #agnet-name'),
            $agent_tel  = $(_pageId+' #agent-tel'),
            $agent_sn   = $(_pageId+' #agent-sn'),
            $agent_yyb  = $(_pageId+' #agent-yyb');

        service.queryBrokerInfo({"broker_no" : agent}, function(data){

            console.log(data);
            layerUtils.iLoading(false);
            if(data.error_no === "0"){
                var result = data.results[0];

                BROKER_INFO['ygbh'] = result['ygbh'];         //编号
                BROKER_INFO['ygxm'] = result['ygxm'];         //姓名
                BROKER_INFO['yddh'] = result['yddh'];         //移动电话
                BROKER_INFO['ygzp'] = result['ygzp'];         //照片

                BRANCH_NO           = Number(result['dwbh']); //营业部编号
                $agent_name.text(result['ygxm']);
                $agent_tel.text(result['yddh']);
                $agent_sn.text(result['zybh']);
                $agent_yyb.text(result['dwmc']);


                appUtils.setSStorageInfo("branchno",BRANCH_NO);
                appUtils.setSStorageInfo("branchname", result['dwmc']);
                appUtils.setSStorageInfo("broker_info",JSON.stringify(BROKER_INFO));

                // 显示经纪人头像
                var image = new Image();
                image.src = global.photoLink +result['ygzp'];
                image.onload = function(){
                    $(_pageId+" .head").attr("src", image.src);
                }

                queryDefaultCommission(BRANCH_NO);

            }else{
                layerUtils.iAlert(data.error_info);
            }

        }, true, true,function(){

            layerUtils.iConfirm("请求超时，是否重新加载？",function(){
                queryDefaultCommission(BRANCH_NO);
            });

        });
    }


    /**
     * [queryDefaultCommission 根据营业部编号查询营业部默认佣金默认佣金]
     * @param  {[int]} branchno [营业部编号]
     */
    function queryDefaultCommission(branchno){

        service.queryBranch({},function(data){
            console.log(data);

            var commissionList = data.commissionList;
            for(var n = 0; n < commissionList.length ; n++ ){
                if(commissionList[n]['branchcode'] == branchno){
                    COMMISSION = commissionList[n]['commission'];
                    // if(SHOW_SETTING == ''){
                    //     $(_pageId+' #agent-commission').val('');
                    // }else{
                    //     $(_pageId+' #agent-commission').val(COMMISSION*100)
                    // }
                    $(_pageId+' #agent-commission').val(COMMISSION*100);
                    return;
                }
            }
        })
    }

    // 向选定的经纪人短信

    /**
     * [sendSmsToBroker description]
     * @param  {Boolean} isChanged [佣金是为营业部默认佣金]
     *
     * 给经纪人发送信息 确认佣金
     *
     */
    function sendSmsToBroker(isChanged){

        var $agent_tel       = $(_pageId+' #agent-tel'),         // 经纪人手机号
            $commission      = $(_pageId+' #agent-commission');  // 填入的佣金

        var broker_mobile_no = $agent_tel.text(),
            commission       = $commission.val();

        var param = {
            "op_way"           : iBrowser.pc ? 0 : 3,   // 访问接口来源标识 0：pc， 2：pad， 3：手机
            "mobile_no"        : MOBILE_NO,
            "broker_mobile_no" : broker_mobile_no,       //经纪人手机号
            "ip"               : iBrowser.pc ? "192.168.1.109" : "",
            "mac"              : iBrowser.pc ? "02:00:5E:00:00:14" : "",
            "isBroker"         : "1",
            "identify_code"    : commission                    //填入的佣金
        };

        if(!isChanged){
            param.isNeedCode = "0";
        }

        service.getSmsCode(param, function(data){
            if(data.error_no === "0"){
                // 没有改变默认佣金 则直接绑定经纪人
                if(!isChanged){
                    bindBroker();
                }else{
                    //佣金经过手工调整 给经纪人发送短信
                    layerUtils.iAlert("验证码短信发送成功!");
                    intervalClock();
                }

            }else{
                layerUtils.iAlert(data.error_info);
            }
        });
    }


    /**
     * [intervalClock 验证码发送按钮倒倒计时]
     * @param  {int} time 倒计时次数 (每次1秒)
     *
     * 倒计时过程中 手机号设为只读 倒计时完成后设为可编辑
     *
     */
    function intervalClock(time){

        var $btn_verify =  $(_pageId + " .btn-verify"),           // 验证码按钮
            $txt_commission  = $(_pageId + " #agent-commission"); // 手机号表单

        time = time||60;

        $btn_verify.addClass('disabled').text(time+"秒后重发");  //验证码按钮倒计时
        $txt_commission.attr('readonly','readonly');             //将佣金输入框设为只读

        INTERVAL = window.setInterval(function() {
            time--;
            if(time == 0){
                window.clearInterval(INTERVAL);
                $btn_verify.removeClass('disabled').text('发送验证码');
                $txt_commission.removeAttr('readonly');
                return;
            }
            $btn_verify.text(time + "秒后重发");
        },1000);
    }


    // 校验用户输入的确认码，成功后进入下一步
    function checkSmsCode(){

        var broker_mobile_no  = $(_pageId+' #agent-tel').text(),
            mobile_code       = $(_pageId+' #broker-verify input').val(); //经纪人的确认码

        if(!mobile_code){
            layerUtils.iAlert('验证码不能为空！');
            return;
        }

        var param = {
            "login_type"       : "1",
            "mobile_no"        : MOBILE_NO,             //  用户手机号
            "broker_mobile_no" : broker_mobile_no,      //  经纪人手机号
            "mobile_code"      : mobile_code,           //  经纪人的确认码
            "login_flag"       : "0"
        };
        service.getOpenInfo(param, function (data) {
            var error_no = data.error_no,
                error_info = data.error_info;
            if(error_no === "0"){
                bindBroker();
            }else{
                layerUtils.iAlert(error_info);
            }
        });
    }



    // 绑定客户与经纪人关系
    function bindBroker(){

        var agent_commission = $(_pageId+' #agent-commission').val();  //用户填充的佣金值

        var param = {
            "userid"        : USER_ID,
            "broker_no"     : BROKER_INFO['ygbh'],
            "broker_name"   : BROKER_INFO['ygxm'],
            "mobileno"      : BROKER_INFO['yddh'],
            "identify_code" : "万分之" + agent_commission
        };

        var commission = utils.floatDivOpera(agent_commission,10000);

        service.bindBroker(param, function(data){
            var error_no = data.error_no,
                error_info = data.error_info;
            if(error_no === "0"){
                appUtils.setSStorageInfo("commission",commission);
                clearInterval(INTERVAL);
                appUtils.pageInit("account/brokerInfo","account/uploadPhoto");
            }else{
                layerUtils.iAlert(error_info);
            }
        });
    }

    /**
     * [checkCommission 佣金值校验]
     * @param  {[type]} commission [佣金值]
     *
     * 佣金校验规则
     *
     * 1.必须为合法数字
     * 2.可为整数或一位小数浮点数
     * 3.输入的值必须在营业部默认佣金与最高佣金(30/10000)之间
     *
     */
    function checkCommission(commission){

        commission = Number(commission);

        if(commission === 0){
            layerUtils.iAlert('佣金不能为空!');
            return false;
        }

        if(!validatorUtil.isNumberFloat(commission)){
            layerUtils.iAlert('请输入合法数值!');
            return false;
        }

        if(commission > 30){
            layerUtils.iAlert('最高佣金不能高于万分之三十!');
            return false;
        }

        if(commission < COMMISSION*100){
            layerUtils.iAlert('佣金不能低于营业部默认值!');
            return false;
        }

        var commission_str = commission.toString();

        if(commission.toString().indexOf(".") !== -1 && commission.toString().split(".")[1].length > 1){
            layerUtils.iAlert('最多保留一位小数!');
            return false;
        }
        return true;
    }


    module.exports = {
        "init" : init,
        "bindPageEvent" : bindPageEvent,
        "destroy" : destroy
    };
});
