/**
 * 手机号码验证---sdk
 */
define(function(require, exports, module) {

	var service        = require("serviceImp").getInstance(), //业务层接口，请求数据
		global         = require("gconfig").global,
		validatorUtil  = require("validatorUtil"),
		layerUtils     = require("layerUtils"),
		appUtils       = require("appUtils"),
		_pageId        = "#account_msgVerify",
		EXTEND_COMPANY,
		USER_ID,
		INTERVAL;

	function init() {

		var channel     = getQueryString("channel");
		var agent       = getQueryString("agent");
		var showsetting = getQueryString("showsetting");
		var recommandNo = $(_pageId+' .recommand-no');

		appUtils.clearSStorage();

		if(agent){
			recommandNo.val(agent).attr('readonly','readonly');
		}

		appUtils.setSStorageInfo("channel", channel);
		appUtils.setSStorageInfo("agent", agent);
		appUtils.setSStorageInfo("showsetting", showsetting);

		// 将渠道信息写入section

		if (channel) {
			service.queryChannel({
				"id": channel
			}, function(data) {
				var results = data.results[0];
				EXTEND_COMPANY = results.name;
				appUtils.setSStorageInfo("channelInfo", JSON.stringify(results));
			})
		}
	}

	function bindPageEvent() {

		var $btn_verify = $(_pageId + " .btn-verify"),      // $验证码按钮
			$phone      = $(_pageId + " .phone"),           // $手机号表单
			$verifyCode = $(_pageId + " .verifycode"),     // $验证码
			$show_bank  = $(_pageId + " .show-bank-list"),
			$next       = $(_pageId + " .btn-next-step");   // 下一步按钮

		/* 绑定获取短信验证码事件 */
		appUtils.bindEvent($btn_verify, function() {

			var phoneNum = $phone.val();

			if($btn_verify.hasClass('disabled')){ //按钮禁用状态
				return;
			}

			if(!phoneNum){
				layerUtils.iAlert("请先输入手机号码！");
				return;
			}

			if (!validatorUtil.isMobile(phoneNum)) {
				layerUtils.iAlert("您输入的手机号码不正确！");
				return;
			}

			sendMsg(phoneNum);

		});

        // 查看示例
        appUtils.bindEvent($show_bank,function(e){
            e.preventDefault();
            var demo_str = '<div class="overlay">'+
                                '<div class="info-window mt-40">'+
                                    '<div class="pic-demo"><img src="images/bank_list.png" width="100%" height="auto" alt=""></div>'+
                                    '<div class="info-window-btn">我知道了</div>'+
                                '</div>'+
                            '</div>';
            $(_pageId).append(demo_str);
        });
        appUtils.preBindEvent(_pageId,'.info-window-btn',function(){
            $(_pageId+' .overlay').remove();
        });


		//绑定input输入事件
		appUtils.bindEvent($phone, function() {
			$btn_verify.show();
		},'focus');

		//根据手机号码与验证码的输入情况确定是否灰掉【下一步】按钮
		appUtils.bindEvent($phone, function() {
			checkNextBtnState();
		},'input');
		appUtils.bindEvent($verifyCode,function() {
			checkNextBtnState();
		},'input');

		// 下一步(继续开户)
		appUtils.bindEvent($next, function() {
			if($(this).hasClass('disabled')){
				return;
			}
			if (validateCode()) {
				submitMobileCode(); //验证码校验
			}
		});
	}


	//检查下一步按钮的状态
	function checkNextBtnState(){
		var	$phone      = $(_pageId + " .phone"),           // $手机号表单
			$verifyCode =  $(_pageId + " .verifycode"),     // $验证码
			$next       = $(_pageId + " .btn-next-step");   // 下一步按钮

		if($phone.val() && $verifyCode.val()){
			$next.removeClass('disabled');
		}else{
			$next.addClass('disabled');
		}
	}


    /**
     * validateCode 验证输入数据
     * @return {[Boolean]}  通过验证则返回true
     */
	function validateCode() {

		var phoneNum   = $(_pageId + " .phone").val(),      // 手机号
			verifyCode = $(_pageId + " .verifycode").val()  // 验证码

		if (phoneNum.length == 0) {
			layerUtils.iAlert("请输入手机号！");
			return false;
		}
		if (!validatorUtil.isMobile(phoneNum)) {
			layerUtils.iAlert("您输入的手机号码不正确，请输入11位手机号码！");
			return false;
		}
		if (phoneNum.length == 0) {
			layerUtils.iAlert("请输入验证码！");
			return false;
		}
		if (!validatorUtil.isNumeric(verifyCode)) {
			layerUtils.iAlert("验证码格式错误！");
			return false;
		}
		return true;
	}

	function destroy() {

		var $btn_verify     = $(_pageId + " .btn-verify"),      // $验证码按钮
			$txt_phone      = $(_pageId + " .phone"),           // $手机号表单
			$txt_verifyCode = $(_pageId + " .verifycode");      // $验证码

			$btn_verify.hide();                                 // 隐藏按钮
			$txt_phone.val("");                                 // 清空表单
			$txt_verifyCode.val("");                            // 清除验证码
			service.destroy();                                  // 销毁service
			clearInterval(INTERVAL);
	}


    /**
     * [sendMsg 发送短信]
     * @param  {int} phoneNum  手机号码
     */
	function sendMsg(phoneNum) {

		var mac    = iBrowser.pc ? "02:00:5E:00:00:14" : "",
			ip     = iBrowser.pc ? "192.168.1.109" : "",
			op_way = iBrowser.pc ? 0 : 3;                     // 访问接口来源标识，访问来源(默认PC) 0：pc， 2：pad， 3：手机

		var param  = {
			"op_way"   : op_way,
			"mobile_no": phoneNum,
			"ip"       : ip,
			"mac"      : mac
		};

		//请求获取验证码接口
		service.getSmsCode(param, function(data) {

			if (data.error_no == "0") {

				if (data.results[0] && data.results[0]['ip']) { //后台如果返回ip地址，则本地存储用户ip地址
					appUtils.setSStorageInfo("ip", data.results[0]['ip']);
				}

				intervalClock(); //设置按钮倒计时

			} else {
				layerUtils.iAlert(data.error_info, -1);
				return false;
			}
		});
	}


	/**
	 * [intervalClock 验证码发送按钮倒倒计时]
	 * @param  {int} time 倒计时次数 (每次1秒)
	 *
	 * 倒计时过程中 手机号设为只读 倒计时完成后设为可编辑
	 *
	 */
	function intervalClock(time){

		var $btn_verify =  $(_pageId + " .btn-verify"),     // 验证码按钮
			$txt_phone  = $(_pageId + " .phone");           // 手机号表单
		time = time||120;

		$btn_verify.addClass('disabled').text(time+"秒后重发");
		$txt_phone.attr('readonly','readonly');

		INTERVAL = setInterval(function() {
			time--;
			if(time == 0){
				clearInterval(INTERVAL);
				$btn_verify.removeClass('disabled').text('发送验证码');
				$txt_phone.removeAttr('readonly');
				return;
			}
			$btn_verify.text(time + "秒后重发");
		},1000);
	}



	/* 提交验证码校验 */
	function submitMobileCode() {
		var mobile_no  = $(_pageId + " .phone").val(),
			verifyCode = $(_pageId + " .verifycode").val(),
			weixin     = appUtils.getSStorageInfo("weixin");

		var param = {
			"login_type"     : "1",
			"weixin"         : weixin,
			"company"        : "",
			"extend_company" : EXTEND_COMPANY||'微证券',
			"mobile_no"      : mobile_no,
			"mobile_code"    : verifyCode,
			"login_flag"     : "0"     // 登录业务标准，新开户0  转户1  理财户2,9一人多户
		};
		/*调用验证码校验接口*/
		service.getOpenInfo(param, function(data) {
			var error_no   = data.error_no,
			    error_info = data.error_info,
			    result     = data.resultInfo,
				rejectInfo = data.bhmessageList;


			if(error_no != "0"){
				layerUtils.iAlert(error_info);
				return;
			}

			storeInfo(result[0]);//存储用户身份信息
			goNextStep(result,rejectInfo);

		});
	}


	function goNextStep(result,rejectInfo){
		//有驳回信息，走驳回流程
		if(result[0]['need_photo_front']==1||result[0]['need_photo_back']==1||result[0]['need_third_deposit']==1||result[0]['need_video']==1){
			appUtils.setSStorageInfo("rejectInfo", JSON.stringify(rejectInfo));    // 存储驳回原因
			goRejectStep(result[0]); //走驳回流程
			return;
		}

		goNormalStep(result[0]); //走正常流程
	}


	/**
	 * [storeInfo 将用户信息存储到session]
	 * @param  {obj} info
	 * 个人身份信息
	 * 可能的驳回情况：
	 * 1.身份信息 含身份证正面、反面
	 * 2.三方存管
	 * 3.视频录制 含上传大头照
	 */
	function storeInfo(info){

		var infoParam = {
			custname    : info.custname,        // 姓名
			addr        : info.addr,            // 地址
			idno        : info.idno,            // 身份证号码

			policeorg   : info.policeorg,       // 签发机关
			idbegindate : info.idbegindate,	    // 起始日期
			idenddate   : info.idenddate	    // 结束日期
		};

		appUtils.setSStorageInfo("infoParam", JSON.stringify(infoParam));


		//用户id
		if (info.user_id) {
			USER_ID = info.user_id;
			appUtils.setSStorageInfo("user_id", info.user_id);
		}
		// 身份证号保存到session
		if (info.idno) {
			appUtils.setSStorageInfo("idCardNo", info.idno);
		}
		//手机号保存到session
		if (info.mobileno) {
			appUtils.setSStorageInfo("mobileNo", info.mobileno);
		}
		// 将客户姓名保存到 session 中
		if (info.custname) {
			appUtils.setSStorageInfo("custname", info.custname);
		}
		// 签发机关保存到session
		if (info.policeorg) {
			appUtils.setSStorageInfo("policeorg", info.policeorg);
		}
		// 证件地址保存到session
		if (info.native) {
			appUtils.setSStorageInfo("native", info.native);
		}
		// 联系地址保存到session
		if (info.addr) {
			appUtils.setSStorageInfo("addr", info.addr);
		}
		// 起始期限保存到session
		if (info.idbegindate) {
			appUtils.setSStorageInfo("idbegindate", info.idbegindate);
		}
		// 结束期限保存到session
		if (info.idenddate) {
			appUtils.setSStorageInfo("idenddate", info.idenddate);
		}
		// 邮编保存到session
		if (info.postid) {
			appUtils.setSStorageInfo("postid", info.postid);
		}
		// 职业保存到session
		if (info.profession_code) {
			appUtils.setSStorageInfo("profession_code", info.profession_code);
		}
		// 学历保存到session
		if (info.edu) {
			appUtils.setSStorageInfo("edu", info.edu);
		}
		// 将 clientinfo 保存到 session 中，用于解决壳子上传照片的权限问题
		if (info.clientinfo) {
			appUtils.setSStorageInfo("clientinfo", info.clientinfo);
		}
		// 将 jsessionid 保存到 session 中，用于解决壳子上传照片的权限问题
		if (info.jsessionid) {
			appUtils.setSStorageInfo("jsessionid", info.jsessionid);
		}
		// 将佣金id保存到session
		if (info.commission) {
			appUtils.setSStorageInfo("commission", info.commission);
		}
		// 将佣金值保存到session
		if (info.commissionname) {
			appUtils.setSStorageInfo("commissionname", info.commissionname);
		}
		// 将营业部Id保存到session
		if (info.branchno) {
			appUtils.setSStorageInfo("branchno", info.branchno);
		}
		// 将营业部名称保存到session
		if (info.branchname) {
			appUtils.setSStorageInfo("branchname", info.branchname);
		}
		// 将省份保存到session
		if (info.provincename) {
			appUtils.setSStorageInfo("provincename", info.provincename);
		}
		// 将城市保存到session
		if (info.cityname) {
			appUtils.setSStorageInfo("cityname", info.cityname);
		}
		// 将视频状态保存到session
		if (info.witness_flag) {
			appUtils.setSStorageInfo("witness_flag", info.witness_flag);
		}
		// 将公安校验保存到session
		if (info.police_flag) {
			appUtils.setSStorageInfo("police_flag", info.police_flag);
		}

		var rejectStep = {};

		// 需要重传身份证信息
		if(info.need_photo_front==1||info.need_photo_back==1){
			rejectStep.backUploadPhoto = 1;
		}
		// 需要重新绑定三方存管信息
		if(info.need_third_deposit==1){
			rejectStep.backThirdDepository = 1;
		}
		// 需要重新视频认证
		if(info.need_video==1){
			rejectStep.backPostConfirm = 1
		}

		appUtils.setSStorageInfo("rejectStep", JSON.stringify(rejectStep));  //存储驳回的步骤

		appUtils.setSStorageInfo("shaselect", info.shaselect);  // 是否选择沪A
		appUtils.setSStorageInfo("szaselect", info.szaselect);  // 是否选择深A
		appUtils.setSStorageInfo("hacnselect", info.shaselect); // 是否选择沪开放式基金
		appUtils.setSStorageInfo("zacnselect", info.szaselect); // 是否选择深开放式基金
	}


	/**
	 * [goRejectStep 走驳回流程]
	 * @param  {[type]} info [description]
	 * 1.驳回身份证
	 * 2.驳回开设股东账户
	 * 3.驳回三方存管
	 *
	 */
	function goRejectStep(info){

		// 1.补全身份证
		if (info['need_photo_front']==1||info['need_photo_back']==1) {
			appUtils.pageInit("account/msgVerify", "account/backUploadPhoto");
			return;
		}

		// 2.驳回三方存管
		if (info['need_third_deposit']==1) {
			appUtils.pageInit("account/msgVerify", "account/backThirdDepository");
			return;
		}
		// 3.驳回视频录制
		if (info['need_video']==1) {
			appUtils.pageInit("account/msgVerify", "account/backPostConfirm");
			return;
		}
	}

	/**
	 * [goNormalStep 走常规流程]
	 * @param  {[type]} info [description]
	 *
	 * 1.如果有断点 则走断点步骤
	 * 2.如果有经纪人信息 则去确认佣金
	 * 3.走常规流程
	 *
	 */
	function goNormalStep(info){

		var current = info.lastcomplete_step,
			map     = {
				"uploadimg"   : "account/uploadPhoto",         // 上传照片
				"idconfirm"   : "account/personInfo",          // 个人信息
				"stkacct"     : "account/signProtocol",        // 签署协议
				"setpwd"      : "account/setPwd",              // 设置密码
				"tpbank"      : "account/thirdDepository",     // 三方存管
				"risksurvey"  : "account/riskAssessment",      // 风险测评
				"visitsurvey" : "account/openConfirm",         // 问卷回访
				"witness"     : "account/postConfirm",         // 视频认证
				"success"     : "account/success"              // 结果
			},
			steps   = [
				"uploadimg",
				"idconfirm",
				"stkacct",
				"setpwd",
				"tpbank",
				"risksurvey",
				"visitsurvey",
				"witness",
				"success"
			],

			index   = steps.indexOf(current);

		//如果是断点流程则继续从上次未完成的步骤开始
		if(index > -1 && index < steps.length-1){
			var next = steps[index+1];

			if(next == "witness" && info.witness_flag == 1){
				//如果断点是上传视频，而上传视频的标识为true 则直接到结果页
				appUtils.pageInit("account/msgVerify", map["success"]);
				return;
			}

			appUtils.pageInit("account/msgVerify", map[next]);
			return;
		}

		//验证推荐码是否正确
		var recommandNo = $(_pageId+' .recommand-no');
		var agent       = recommandNo.val();


		if(!agent){ //没有推荐码直接设置佣金
			//setCommission(); //选择互联网营业部
			appUtils.pageInit("account/msgVerify", "account/selDepartment");
			return;
		}

		//有推荐码
		service.queryBrokerInfo({"broker_no" : agent},function(data){

			if(data && data.error_no == 0){ //推荐码为经纪人推荐码 走展业流程
				appUtils.setSStorageInfo('agent',agent);
				appUtils.pageInit("account/msgVerify", "account/brokerInfo");
				return;
			}

			//用户填了推荐码  但该推荐码不为经纪人推荐码 则直接设置佣金
			appUtils.setSStorageInfo('recommand_no',agent);

			appUtils.pageInit("account/msgVerify", "account/selDepartment");
			//setCommission();//选择互联网营业部
		})

	}


    /**
     * bindBroker 在微证券sdk客户端中绑定推荐码
     * @param  string  agent 推荐码
     *
     */
    function bindBrokerInSdk(agent,commission){
        var agent_commission = global.defaultCommission;  //用户填充的佣金值

        var param = {
            "userid"        : USER_ID,
            "broker_no"     : 'A'+agent,
            "broker_name"   : '微证券',
            "mobileno"      : '18888888888',
            "identify_code" : "万分之" + ( commission*100 )
        };

        service.bindBroker(param, function(data){
            if(data.error_no === "0"){
                appUtils.pageInit("account/msgVerify","account/uploadPhoto");
            }else{
                layerUtils.iAlert(data.error_info);
            }
        });
    }

    /**
     *  SDK中指定的营业部为西藏营业部
     *  佣金为西藏营业部佣金
     */
    function setCommission(){

        service.queryBranch({},function(data){

        	var commission_list = data.commissionList;
        	var commission      = null;
        	var branch_no       = global.zdBranchId;


	        for(var i = 0; i < commission_list.length ; i++ ){
	            if(commission_list[i]['branchcode'] == branch_no){
	                commission = commission_list[i]['commission'];
	                break;
	            }
	        }

	        appUtils.setSStorageInfo("branchno",global.zdBranchId);     // 营业部id
	        appUtils.setSStorageInfo("commission", commission);        // 佣金信息
	        appUtils.pageInit("account/msgVerify", "account/uploadPhoto");
        })
    }

	//暴露接口
	module.exports = {
		"init": init,
		"bindPageEvent": bindPageEvent,
		"destroy": destroy
	};

});
