/**
 * 选择营业部
 */
define(function(require, exports, module) {

    var appUtils       = require("appUtils"),
        service        = require("serviceImp").getInstance(), //业务层接口，请求数据
        global         = require("gconfig").global,
        layerUtils     = require("layerUtils"),
        _pageId        = "#account_selDepartment",

        PROVINCE_LIST,           // 省
        CITY_LIST,               // 市
        BRANCH_LIST,             // 营业部
        COMMISSION_LIST,         // 佣金

        BRANCH_PARAM = {
            branchno  : null,   // 选择的营业部
            commission: null    // 选择的佣金
        };

    var CHANNEL,
        BRANCH_NO,
        CHANNEL_INFO;


    function init() {

        CHANNEL      = appUtils.getSStorageInfo("channel"),
        BRANCH_NO    = appUtils.getSStorageInfo("branchno"),
        CHANNEL_INFO = appUtils.getSStorageInfo("channelInfo");

        initBranchInfo();
    }

    function bindPageEvent() {

        var $provinceList = $(_pageId + ' #select-privince'),
            $cityList     = $(_pageId + ' #select-city'),
            $branchList   = $(_pageId + ' #select-branch'),
            $next         = $(_pageId + ' .btn-next-step');

            //切换省份列出相应的城市 清除营业部列表
            appUtils.bindEvent($provinceList, function() {
                var provinceNo = $provinceList.val();

                $branchList.html(' <option value="">请选择营业部</option>');
                getCityByProvinceID(provinceNo);

                $branchList.trigger('change');
            },"change")

             //根据城市列出相应城市的营业部
            appUtils.bindEvent($cityList, function() {
                var cityNo = $cityList.val();
                $branchList.html(' <option value="">请选择营业部</option>');

                if(cityNo){
                    getBranchByCityID(cityNo);
                }
                $branchList.trigger('change');
            },"change")

            //根据所选的营业部确定佣金信息
            appUtils.bindEvent($branchList, function() {
                var branchCode = $branchList.val(),
                    branchname = $branchList.find('option:selected').text();

                if(branchCode){
                    appUtils.setSStorageInfo("branchname", branchname); //保存营业部名称 在查询结果的时候会用到
                    getCommissionByBranchID(branchCode);
                    $next.removeClass('disabled');
                }else{
                    //如果没有营业部编号则清空已选择的营业部信息
                    BRANCH_PARAM.branchno   = null;
                    BRANCH_PARAM.commission = null;
                    $next.addClass('disabled');
                }
            },"change")

            // 下一步按钮
            appUtils.bindEvent($next, function() {  //根据所选的营业部确定佣金信息
                if($(this).hasClass('disabled')){
                    return;
                }

                appUtils.setSStorageInfo("branchno", BRANCH_PARAM.branchno);     // 营业部id
                appUtils.setSStorageInfo("commission", BRANCH_PARAM.commission); // 佣金信息
                appUtils.pageInit("account/selDepartment", "account/uploadPhoto");
            })
    }

    function destroy() {
        service.destroy();
    }


    // 获取省份列表
    function getProvinceList(){

        var $provinceList = $(_pageId + ' #select-privince'),
            $cityList     = $(_pageId + ' #select-city'),
            $branchList   = $(_pageId + ' #select-branch');

        var privinceHtmlStr = '<option value="">请选择省份</option>';

        for(var i = 0;i < PROVINCE_LIST.length;i++){
            privinceHtmlStr += '<option value="'+PROVINCE_LIST[i]['provinceno'] +'">'+PROVINCE_LIST[i]['provincename']+'</option>';
        }
        $provinceList.html(privinceHtmlStr);
        $cityList.html('<option value="">请选择城市</option>');
        $branchList.html('<option value="">请选择营业部</option>');
    }

    // 根据省份ID选择城市
    function getCityByProvinceID(id){

        var $cityList     = $(_pageId + ' #select-city'),
            cityOptionStr = ' <option value="">请选择城市</option>';
        if(!id){
            $cityList.html(cityOptionStr);
            return;
        }

        for(var i = 0;i < CITY_LIST.length;i++){
            if(CITY_LIST[i]['provincenno'] == id){
                cityOptionStr += '<option value="'+CITY_LIST[i]['cityno'] +'">'+CITY_LIST[i]['cityname']+'</option>';
            }
        }

         $cityList.html(cityOptionStr);
    }

    // 根据城市ID选择营业部
    function getBranchByCityID(id){

        var $branchList     = $(_pageId + ' #select-branch'),
            branchOptionStr = ' <option value="">请选择营业部</option>';
        if(!id){
            $branchList.html(branchOptionStr);
            return;
        }

        for(var i = 0;i < BRANCH_LIST.length;i++){
            if(BRANCH_LIST[i]['cityno'] == id){
                branchOptionStr += '<option value="'+BRANCH_LIST[i]['branchcode'] +'">'+BRANCH_LIST[i]['branchname']+'</option>';
            }
        }


        if( id != '281'){//指定营业部 非西藏拉拉萨选择互联网营业部
            for(var m = 0;m<BRANCH_LIST.length;m++){
                if(BRANCH_LIST[m]['branchcode'] == global.zdBranchId){
                    branchOptionStr += '<option value="'+BRANCH_LIST[m]['branchcode'] +'">'+BRANCH_LIST[m]['branchname']+'</option>';
                }
            }
        }



        $branchList.html(branchOptionStr);
    }


    //根据营业部编码获取佣金信息
    function getCommissionByBranchID(id){
        for(var i = 0;i<COMMISSION_LIST.length;i++){
            if(COMMISSION_LIST[i]['branchcode'] == id){
                BRANCH_PARAM.branchno   = id;
                BRANCH_PARAM.commission = COMMISSION_LIST[i]['commission'];
                console.log(BRANCH_PARAM);
                return;
            }
        }
    }

    /**
     * initBranchInfo
     *
     * 1.获取营业部信息,包含省份信息，城市信息，营业部信息 佣金信息等
     * 2.判断用户渠道信息，并初始化选择表单
     */
    function initBranchInfo(){
        var $provinceList = $(_pageId + ' #select-privince'),
            $cityList     = $(_pageId + ' #select-city'),
            $branchList   = $(_pageId + ' #select-branch');

        service.queryBranch({},function(data){
            console.log(data);

            PROVINCE_LIST   = data.provinceList;
            CITY_LIST       = data.cityList;
            BRANCH_LIST     = data.branchList;
            COMMISSION_LIST = data.commissionList;

            //如果有渠道信息 则根据渠道信息填充营业部信息
            if(CHANNEL){
                getChannelInfo();
                return;
            }
            if(BRANCH_NO){
                getCachedInfo()
                return;
            }

            // 没有渠道信息 获取省份列表
            getProvinceList();
        })
    }

    /**
     * [getCachedInfo 根据渠道信息 填充表单]
     * @return {[type]} [description]
     */
    function getCachedInfo(){


        var cityno,
            provinceno,

            $provinceList = $(_pageId + ' #select-privince'),
            $cityList     = $(_pageId + ' #select-city'),
            $branchList   = $(_pageId + ' #select-branch'),
            $next         = $(_pageId + ' .btn-next-step');

        //遍历营业部列表获取 cityno 填充营业部信息

        var html_branch ='<option value="">请选择营业部</option>';
        for(var i = 0;i < BRANCH_LIST.length;i++){

            if(BRANCH_LIST[i]['branchcode'] == BRANCH_NO){
                cityno = BRANCH_LIST[i]['cityno']
                html_branch += '<option selected="selected" value="'+BRANCH_LIST[i]['branchcode'] +'">'+BRANCH_LIST[i]['branchname']+'</option>';
                continue;
            }

            html_branch += '<option value="'+BRANCH_LIST[i]['branchcode'] +'">'+BRANCH_LIST[i]['branchname']+'</option>';
        }
        $branchList.html(html_branch);

        //遍历城市列表 获取provinceno 填充城市信息

        var html_city ='<option value="">请选择城市</option>';
        for(var x = 0; x <CITY_LIST.length;x++){
            if(CITY_LIST[x]['cityno'] == cityno){
                provinceno = CITY_LIST[x]['provincenno'];
                html_city += '<option selected="selected" value="'+CITY_LIST[x]['cityno'] +'">'+CITY_LIST[x]['cityname']+'</option>';
                continue;
            }

            html_city += '<option value="'+CITY_LIST[x]['cityno'] +'">'+CITY_LIST[x]['cityname']+'</option>';
        }
        $cityList.html(html_city);

        //遍历省份列表  填充城市信息
        var html_province ='<option value="">请选择省份</option>';
        for(var m = 0; m <PROVINCE_LIST.length; m++){

            if(PROVINCE_LIST[m]['provinceno'] == provinceno){
                html_province +='<option selected="selected" value="'+PROVINCE_LIST[m]['provinceno'] +'">'+PROVINCE_LIST[m]['provincename']+'</option>';
                continue;
            }

            html_province +='<option value="'+PROVINCE_LIST[m]['provinceno'] +'">'+PROVINCE_LIST[m]['provincename']+'</option>';
        }
        $provinceList.html(html_province);

        //遍历佣金列表 设置佣金参数
        for(var n = 0; n < COMMISSION_LIST.length ; n++ ){
            if(COMMISSION_LIST[n]['branchcode'] == BRANCH_NO){
                BRANCH_PARAM.branchno   = BRANCH_NO;
                BRANCH_PARAM.commission = COMMISSION_LIST[n]['commission'];
                break;
            }
        }

        $next.removeClass('disabled');
    }

    /**
     * [getChannelInfo 根据渠道信息 填充表单]
     * @return {[type]} [description]
     */
    function getChannelInfo(){

        CHANNEL_INFO = JSON.parse(CHANNEL_INFO);

        var cityno,
            provinceno,
            branch_no     = CHANNEL_INFO['branch_no'],

            $provinceList = $(_pageId + ' #select-privince'),
            $cityList     = $(_pageId + ' #select-city'),
            $branchList   = $(_pageId + ' #select-branch'),
            $next         = $(_pageId + ' .btn-next-step');

        //遍历营业部列表获取 cityno 填充营业部信息
        for(var i = 0;i < BRANCH_LIST.length;i++){
            if(BRANCH_LIST[i]['branchcode'] == branch_no){
                cityno = BRANCH_LIST[i]['cityno']
                $branchList
                    .html('<option selected="selected" value="'+BRANCH_LIST[i]['branchcode'] +'">'+BRANCH_LIST[i]['branchname']+'</option>')
                    .attr('disabled','disabled');

                appUtils.setSStorageInfo("branchname", BRANCH_LIST[i]['branchname']);
                break;
            }
        }

        //遍历城市列表 获取provinceno 填充城市信息
        for(var x = 0; x <CITY_LIST.length;x++){
            if(CITY_LIST[x]['cityno'] == cityno){
                provinceno = CITY_LIST[x]['provincenno'];
                $cityList
                    .html('<option selected="selected" value="'+CITY_LIST[x]['cityno'] +'">'+CITY_LIST[x]['cityname']+'</option>')
                    .attr('disabled','disabled');
                break;
            }
        }

        //遍历省份列表  填充城市信息
        for(var m = 0; m <PROVINCE_LIST.length; m++){

            if(PROVINCE_LIST[m]['provinceno'] == provinceno){
                $provinceList
                    .html('<option selected="selected" value="'+PROVINCE_LIST[m]['provinceno'] +'">'+PROVINCE_LIST[m]['provincename']+'</option>')
                    .attr('disabled','disabled');

                break;
            }
        }

        //遍历佣金列表 设置佣金参数
        for(var n = 0; n < COMMISSION_LIST.length ; n++ ){
            if(COMMISSION_LIST[n]['branchcode'] == branch_no){
                BRANCH_PARAM.branchno   = branch_no;
                BRANCH_PARAM.commission = COMMISSION_LIST[n]['commission'];
                break;
            }
        }

        $next.removeClass('disabled');
    }

    // 暴露对外的接口
    module.exports = {
        "init": init,
        "bindPageEvent": bindPageEvent,
        "destroy": destroy
    };
});
