/**
 * 设置密码
 */
define(function(require, exports, module){ 

	var appUtils       = require("appUtils"),
		service        = require("serviceImp").getInstance(),  //业务层接口，请求数据
		global         = require("gconfig").global,
		validatorUtil  = require("validatorUtil"),
		layerUtils     = require("layerUtils"),
		// utils          = require("utils"),
		platform       = require("gconfig").platform,
		endecryptUtils = require("endecryptUtils"),
		
		_pageId        = "#account_setPwd";
		
	var	USER_ID,
		ID_CARD_NO,
		MOBILE_NO;

	function init(){

		USER_ID    = appUtils.getSStorageInfo("user_id");
		ID_CARD_NO = appUtils.getSStorageInfo("idCardNo");
		MOBILE_NO  = appUtils.getSStorageInfo("mobileNo");

		initPage();  // 初始化页面
	}
	
	function bindPageEvent(){

		var $next  = $(_pageId+" .btn-next-step"),
			$pass1 = $(_pageId+" #pass1"),
			$pass2 = $(_pageId+" #pass2");

		//下一步
		appUtils.bindEvent($next,function(){

			if($pass1.val().trim()!== $pass2.val().trim()){
				layerUtils.iAlert("两次输入的密码不一致！");
				$pass1.val('');
				$pass2.val('');
				return;
			}

			if(!validatePassword()){
				$pass1.val('');
				$pass2.val('');
				return;
			}

			postPassword();
			
		});
	}
	
	function destroy(){
		$(_pageId).remove();
		service.destroy();
	}
	
	function initPage(){
		layerUtils.iLoading(false);  // 关闭等待层。。。
		cleanPageElement();  // 清理页面元素
	}
	
	function cleanPageElement(){
		$(_pageId+" input").val('');
	}

	/**
	 * 验证密码 6位数字
	 * 增加弱密校验
	 * 1、出生日期的一部分
	 * 2、证件号码的一部分
	 * 3、某一字符出现的概率不能占总长度的一半以上
	 * 4、顺序递增或者递减
	 * 5、弱密表的控制值
	 * 6、移动电话的一部分
	 * 7、固定电话的一部分
	 */
	function validatePassword(){

		var pwd        = $(_pageId+" #pass1").val().trim();

		//顺序密码库
		var	orderPwdArr = ['012345','123456','234567','345678','456789','987654','876543','765432','654321','543210'];

		//判断弱密码库
		var weakpwdArr = ['111111','222222','333333','444444','555555','666666','777777',
						  '888888','999999','101010','202020','303030','404040','505050',
						  '606060','707070','808080','909090','101010','121212','131313',
						  '141414','151515','161616','171717','181818','191919','202020',
						  '212121','232323','242424','252525','262626','272727','282828',
						  '292929','303030','313131','323232','343434','353535','363636',
						  '373737','383838','393939','404040','414141','424242','434343',
						  '454545','464646','474747','484848','494949','505050','515151',
						  '525252','535353','545454','565656','575757','585858','595959',
						  '606060','616161','626262','636363','646464','656565','676767',
						  '686868','696969','707070','717171','727272','737373','747474',
						  '757575','767676','787878','797979','808080','818181','828282',
                          '838383','848484','858585','868686','878787','898989','909090',
                          '919191','929292','939393','949494','959595','969696','979797',
                          '989898','123412','234523','345634','456745','567856','678967',
                          '123012','123123','234234','345345','456456','567567','678678',
                          '789789','112233','111222','123412','123443','234567','123456',
                          '876543','111122','222233','333344','444455','555566','666677',
                          '777788','888899','999900','111111','111122','111133','111144',
                          '111155','111166','111177','111188','111199','111100'];

        if(!pwd){
			layerUtils.iAlert("密码不能为空");
			return;
        }
			
        if(!/^\d{6}$/.test(pwd)){
			layerUtils.iAlert("资金密码格式错误，请输入6位数字密码！");
			return;
        }
		// 判断是否是移动电话的一部分
		if(MOBILE_NO.indexOf(pwd) != -1){
			layerUtils.iAlert("密码不能是移动电话的一部分！");
			return false;
		}

		// 判断是不是出生日期的一部分
		if(pwd == ID_CARD_NO.substring(6,12) || pwd == ID_CARD_NO.substring(8,14)){
			layerUtils.iAlert("密码不能是出生日期的一部分！");
			return false;
		}

		// 判断是不是证件号码的一部分
		if(ID_CARD_NO.indexOf(pwd) != -1){
			layerUtils.iAlert("密码不能是证件号码的一部分！",-1);
			return false;
		}

		// 判断某一字符出现的次数
		for(var i=0;i<pwd.length;i++){

			var c = pwd.charAt(i),
				count = 0;

			for(var j=0;j<pwd.length;j++){
				if(c == pwd.charAt(j)){
					count++;
				}
			}

			if(count >= 3){
				layerUtils.iAlert("密码中&nbsp;"+c+"&nbsp;出现的次数超过了三次！");
				return false;
			}
		}

		if(orderPwdArr.indexOf(pwd) != -1){
			layerUtils.iAlert("密码不能是顺序递增或递减的数字");
			return false;
		}

		if(weakpwdArr.indexOf(pwd) != -1){
			layerUtils.iAlert("您的密码过于简单");
			return false;
		}


		return true;
	}

	/**
	 * postPassword 提交密码
	 * 
	 * 提交密码分为4个步骤：
	 * 1. 从后台获取RSA公钥
	 * 2. 用RSA公钥对用户输入的密码进行RSA加密
	 * 3. 提交加密后的交易密码
	 * 4. 交易密码提交成功后提交资金密码
	 * 5. 资金密码提交成功后 提交用户私钥
	 * 
	 */
	function postPassword(){

		var $pass1     = $(_pageId+" #pass1"),
			$pass2     = $(_pageId+" #pass2"),
			pwd        = $pass1.val().trim();

		//获取rsa公钥
		service.getRSAKey({}, function(data) {
			if( data.error_no==0){

				//密码采用rsa加密
				var results        = data.results[0];
				var modulus        = results.modulus;
				var publicExponent = results.publicExponent;

				var tpassword      = endecryptUtils.rsaEncrypt(modulus, publicExponent, pwd);  //交易密码
				var fpassword      = endecryptUtils.rsaEncrypt(modulus, publicExponent, pwd);  //资金密码
				var privatekey_pwd = pwd;                                                      //证书密码


				var tradePasswordParam = {
					"user_id"      : USER_ID,
					"acct_clientid": "",
					"password"     : tpassword,
					"pwd_type"     : "2",
					"is_same"      : "1"
				};

				//提交交易密码
				service.setAccountPwd(tradePasswordParam, function(data){

					if(data.error_no==0){//交易密码设置成功，锁定交易密码设置框

						$pass1.attr("readonly","readonly"); //锁定密码框
						$pass2.attr("readonly","readonly");

						var fundPasswordParam  = {
							"user_id"      : USER_ID,
							"acct_clientid": "",
							"password"     : fpassword,
							"pwd_type"     : "1",
							"is_same"      : "1"
						};

						//提交资金密码
						service.setAccountPwd(fundPasswordParam, function(data){
							if( data.error_no==0){//资金密码设置成功

									var param={
										"user_id":USER_ID,
										"privatekey_pwd":privatekey_pwd
										};

									//提交私钥
									service.submitPriKey(param,function(data){

										if(data.error_no == 0){	//调用成功
											appUtils.pageInit("account/setPwd","account/thirdDepository");
										}else{
											layerUtils.iLoading(false);
											layerUtils.iAlert(data.error_info);
										}
									});


							}else{
								layerUtils.iLoading(false);
								layerUtils.iAlert(data.error_info);
							}


						},false);
					}else{
						layerUtils.iLoading(false);
						layerUtils.iAlert(data.error_info);
						return false;
					}
				},false);


			}else{
				layerUtils.iLoading(false);
				layerUtils.iAlert(data.error_info);
			}

		}, false);
	}

	
	// 暴露对外的接口
	module.exports = {
        "init" : init,
        "bindPageEvent" : bindPageEvent,
        "destroy" : destroy
    };
});