/**
 * 签署协议
 */
define(function(require, exports, module){ 
	/* 私有业务模块的全局变量 begin */
	var appUtils       = require("appUtils"),
		service        = require("serviceImp").getInstance(),  //业务层接口，请求数据
		global         = require("gconfig").global,
		layerUtils     = require("layerUtils"),
		// utils          = require("utils"),
		_pageId        = "#account_signProtocol",

		PROTOCOL_ARRAY = [],                            // 存放协议签名值
		ACCOUNT_LIST   = [];                            // 存放要开通的股东账户 1-深A  3-沪A    
		                   
	var	USER_ID,
		IP,
		MAC;

	/* 私有业务模块的全局变量 end */
	
	function init(){

		USER_ID        = appUtils.getSStorageInfo("user_id");
		IP             = appUtils.getSStorageInfo("ip");
		MAC            = appUtils.getSStorageInfo("mac");

		initPage();  // 初始化页面		
	}
	
	function bindPageEvent(){

		var $next        = $(_pageId+' .btn-next-step'),
			$agree_check = $(_pageId+' .agreement input');

		//取消开通账户 弹窗提示
        appUtils.preBindEvent(_pageId+' .market-list','input',function (e) {

            var $this = $(this),
                txt   = $this.attr('data-txt'),
                v     = $this.val(),
                city  = {'1':'深圳','3':'上海'};

            if($this.attr('checked')){

            	e.preventDefault();
				layerUtils.iConfirm(
					'不开通“'+txt+'”账户，您将不能进行'+city[v]+'交易所股票交易，确定取消吗？',
					function(){
						$this.removeAttr('checked');
					},
					function(){return false;},
					"确定",
					"取消"
				);
            }
        });

        appUtils.preBindEvent(_pageId+' .agreement-list', 'a',function (e) {
            e.preventDefault()
            var protocolId = $(this).attr('data-protocolid');
            appUtils.pageInit("account/uploadPhoto", "account/showDigitalProtocol", {"protocolId": protocolId});
        });
		
		/* 继续开户（下一步）*/
		appUtils.bindEvent($next,function(){

			//获取已选择的股东账户
			$(_pageId+' .market-list input').each(function(){
				if($(this).is(':checked')){
					ACCOUNT_LIST.push($(this).val());
				}
			})
			//未选择股东账户
			if(!ACCOUNT_LIST.length){
				layerUtils.iAlert('请选择开通的证券账户！');
				return;
			}
			//未勾选协议
			if(!$agree_check.is(':checked')){
				layerUtils.iAlert('您必须阅读并同意以上协议才能进行证券开户！');
				return;
			}

			submitProtocol();
		});
	}


	/* 初始化页面 */
	function initPage(){
		getMarket();
		getAgreement();
	}
	
	/* 获取市场列表 */
	function getMarket(){

		service.queryDataDict({"enum_type" : "zqzhlx"},function(data){
			layerUtils.iLoading(false);
			if(data.error_no == 0 && data.results.length != 0){
				var html_str='';
				for(var i = 0;i<data.results.length;i++){
					if(data.results[i].item_value == 1 || data.results[i].item_value == 3){
						html_str += '<div class="input-group">'+
			                			'<div class="label">'+data.results[i].item_name+'<input type="checkbox" data-txt="'+data.results[i].item_name+'" checked="checked" value="'+data.results[i].item_value+'" class="form-ctrl-check pull-right"></div>'+
			            			'</div>';
					}
				}
				$(_pageId+" .market-list").html(html_str);
			}else{
				layerUtils.iAlert(data.error_info);
			}
		},false,true,handleTimeout);
	}
	

	
	/**
	 * [getAgreement 获取协议列表]
	 * category_no 1.资金开户协议   2.证券账户开户协议
	 */
	function getAgreement(){
		service.queryProtocolList({"category_no":"1"},function(data){
			console.log(data);
			if(data.error_no == 0 && data.results.length != 0){
				
				var results      = data.results,
					html_str     = "";
				for(var i=0;i<results.length;i++){

					PROTOCOL_ARRAY.push({
						protocol_id : results[i].econtract_no,
						summary     : results[i].econtract_md5
					});

					html_str += '<a data-protocolid="'+results[i].econtract_no +'" data-summary="'+results[i].econtract_md5 +'">《'+results[i].econtract_name+'》</a>';
				}
				$(_pageId+" .agreement-list").html(html_str);
			}else{
				layerUtils.iAlert(data.error_info);
			}
		},true,true,handleTimeout);
	}

	/* 处理请求超时 */
	function handleTimeout(){
		layerUtils.iConfirm("请求超时，是否重新加载？",function(){
			getMarket();
			getAgreement();
		});
	}


	// 提交协议
	function submitProtocol(){
		var param = {
				"user_id"   : USER_ID,
				"jsondata"  : JSON.stringify(PROTOCOL_ARRAY),
				"ipaddr"    : IP,
				"macaddr"   : MAC,
				"checksign" : "0"
		};

		// 新开中登验签
		service.queryOpenCheckSign(param,function(data){

			// 如果有一个协议签署失败，就将签署结果设为 false
		    if(data.error_no == 0){
				openZjAccountAndClient();	//开立账户系统客户号和资金账户
			}else{
				layerUtils.iLoading(false);
				layerUtils.iAlert(data.error_info);
		    }

		},false);		
	}
	
	
	
	/* 开立账户系统客户号和资金账户 */

	function openZjAccountAndClient(){

		var param = {
			"user_id" : USER_ID
		};
		//开立账户系统客户号和资金账户
		service.queryOpenAccount(param,function(data){
			
			var error_no = data.error_no;
			var error_info = data.error_info;
			if(error_no == 0){



				// 开立中登账户
				var param = {
					"user_id"   : USER_ID,
					"sza_str"   : ACCOUNT_LIST.indexOf(1) > -1 ? "1" : "",    // 深A开通情况，不开传空 ，新开 1 ，转户 2
					"sha_str"   : ACCOUNT_LIST.indexOf(3) > -1 ? "1" : "",    // 沪A开通情况
					"szfnd_str" : "",                                        // 深基金开通情况
					"shfnd_str" : "",                                        // 沪基金开通情况
					"opfnd_str" : ""                                         // 通用开发试基金
				};

				//开立中登股东账号
				service.queryOpenCompyAccount(param,function(data){
					layerUtils.iLoading(false);

					if(data.error_no == 0){
						appUtils.pageInit("account/signProtocol","account/setPwd");  //跳转设置密码页面
					}else{
						layerUtils.iAlert(data.error_info);
					}
				},false);


			}else{
				layerUtils.iLoading(false);
				layerUtils.iAlert(error_info);
			}

		},false);
	}

	/* 清理界面元素 */
	function cleanPageElement(){
		$(_pageId+" .market-list").remove();     // 清理证券账户
		$(_pageId+" .agreement-list").remove();  // 清理协议
	}
	
	/*  销毁页面 **/
	function destroy()
	{
		service.destroy();
	}
	
	
	var signProtocol = {
		"init" : init,
		"bindPageEvent" : bindPageEvent,
		"destroy" : destroy
	};

	module.exports = signProtocol;
});