define(function (require, exports, module) {

    var appUtils   = require("appUtils"),
        service    = require("serviceImp").getInstance(), //业务层接口，请求数据
        layerUtils = require("layerUtils"),
        gconfig    = require("gconfig"),
        external   = require("external"), //调用原生壳子
        global     = gconfig.global,
        serverPath = global.serverPath,
        IS_WX      = global.isWX,
        IS_SDK     = global.is_sdk,
        _pageId    = "#account_uploadPhoto",

        IMAGES     = {},

        infoParam  = {
            "idno"       : "",	// 身份证号
            "custname"   : "",	// 客户姓名
            "ethnicname" : "",	// 民族
            "native"     : "",	// 证件地址
            "policeorg"  : "",	// 签发机关
            "birthday"   : "",	// 出生日期
            "idbegindate": "",	// 证件开始日期
            "idenddate"  : "",	// 证件结束日期
            "gender"     : "",	// 用户性别
            "imgPath"    : "",  // 图片的显示地址
            "imgId"      : "",  // 图片 id
            "branchno"   : "",  // 营业部Id
            "commission" : "",  // 佣金套餐
            "postid"     : ""   // 邮编
        };


    var USER_ID, 
        JSESSIONID,
        BRANCH_NO,
        RECOMMEND_NO,
        CLIENT_INFO,
        IP,
        MAC,
        LAST_IMG_TYPE;   // 标识身份证正反面 4-正面 5-反面
        

    require("makeThumb");


    function init() {

        // 存储一个flag，确认已经到达过本页面
        appUtils.setSStorageInfo("hasVisitPhoto", true);

        USER_ID       = appUtils.getSStorageInfo("user_id"); 
        JSESSIONID    = appUtils.getSStorageInfo("jsessionid");
        BRANCH_NO     = appUtils.getSStorageInfo("branchno");
        RECOMMEND_NO  = appUtils.getSStorageInfo("recommend");
        CLIENT_INFO   = appUtils.getSStorageInfo("clientinfo");
        IP            = appUtils.getSStorageInfo("ip");
        MAC           = appUtils.getSStorageInfo("mac");

        cleanPageElement();    // 清理页面元素
        queryCertAgreement();  // 获取中登证书协议
    }

    /* 处理返回按钮 */
    function pageBack() {
        
        if (appUtils.getSStorageInfo("idInfo") == "exist") {
            // 短信登陆，返回至身份证上传，处理返回按钮
            appUtils.pageInit("account/uploadPhoto", "account/selDepartment");
        }else {
            // 正常开户处理返回按钮
            appUtils.pageBack();
        }
    }

    function bindPageEvent() {

        var $positive_btn_area = $(_pageId+' .photo-positive'+','+_pageId+' .btn-positive'),   // 上传身份证正面
            $negative_btn_area = $(_pageId+' .photo-negative'+','+_pageId+' .btn-negative'),   // 上传身份证反面
            $next              = $(_pageId+' .btn-next-step'),                                 // 下一步按钮
            $agreement_sign    = $(_pageId+' .agreement-sign'),                                // 签署协议复选框
            $show_demo         = $(_pageId+' .show-demo');                                     // 查看示例

        // 正面
        appUtils.bindEvent($positive_btn_area,function(){

            if(IS_SDK){
                showShellUploadOption({
                     img_type:4
                });
                return;       
            }

            //微信环境
            if(IS_WX){
                uploadPhotoByWeixin({
                    img_type:4
                });
                return;
            }

            $('#upload-btn-positive').remove(); //先删除
            $(_pageId).append('<input id="upload-btn-positive" type="file" accept="image/*,camera" capture="camera" style="width:0px;height:0px;position:absolute;top:0;left:0;"/>')
            
            $('#upload-btn-positive').makeThumb({
                width: 500,
                height: 500,
                immediate: false,
                success:uploadPositive,
                error:function(obj, state, e){
                    layerUtils.iAlert("系统检测到您手机暂不支持图片上传功能,请更换手机重试！");
                }
            })

            $('#upload-btn-positive').trigger('click');

        });

        //反面
        appUtils.bindEvent($negative_btn_area,function(){

            if(IS_SDK){
                showShellUploadOption({
                     img_type:5
                });
                return;       
            }

            //微信环境
            if(IS_WX){
                uploadPhotoByWeixin({
                    img_type:5,
                });
                return;
            }

            $('#upload-btn-negative').remove(); //先删除
            $(_pageId).append('<input id="upload-btn-negative" type="file" accept="image/*,camera" capture="camera" style="width:0px;height:0px;position:absolute;top:0;left:0;"/>')
            
            $('#upload-btn-negative').makeThumb({
                width: 500,
                height: 500,
                immediate: false,
                success:uploadNegative,
                error:function(obj, state, e){
                    layerUtils.iAlert("系统检测到您手机暂不支持图片上传功能,请更换手机重试！");
                }
            })

            $('#upload-btn-negative').trigger('click');

        });

        // 查看协议
        appUtils.preBindEvent(_pageId+' .agreement label', 'a',function (e) {
            e.preventDefault()
            var protocolId = $(this).attr('data-id');
            appUtils.pageInit("account/uploadPhoto", "account/showDigitalProtocol", {"protocolId": protocolId});
        });

        // 查看示例
        appUtils.bindEvent($show_demo,function(e){
            e.preventDefault();
            var demo_str = '<div class="overlay demo-overlay">'+
                                '<div class="info-window">'+
                                    '<div class="pic-demo"><img src="images/id_demo.png" width="100%" height="auto" alt=""></div>'+
                                    '<div class="info-window-btn">我知道了</div>'+
                                '</div>'+
                            '</div>';
            $(_pageId).append(demo_str);
        });

        //关闭查看示例
        appUtils.preBindEvent(_pageId,'.info-window-btn',function(){
            $(_pageId+' .demo-overlay').remove();
        });


        //用相机拍照
        appUtils.preBindEvent(_pageId,'.btn-camera',function(){
            console.log('使用相机拍照...');
            var img_type = $(_pageId+' .select-list').attr('data-img-type');
            $(_pageId+' .select-overlay').remove();

            uploadPhotoByShell({
                img_type:img_type,
                action:'pai'
            })

        });

        //从相册选择
        appUtils.preBindEvent(_pageId,'.btn-album',function(){
            console.log('从相册选择...');
            var img_type = $(_pageId+' .select-list').attr('data-img-type');
            $(_pageId+' .select-overlay').remove();

            uploadPhotoByShell({
                img_type:img_type,
                action:'phone'
            })
        });

        //关闭 选择照片\相册 （原生）
        appUtils.preBindEvent(_pageId,'.select-cancel-btn',function(){
        
            $(_pageId+' .select-list').removeClass('active');

            setTimeout(function(){
                $(_pageId+' .select-overlay').remove();
            },200);

            
        });

        // 更改签署协议勾选框
        appUtils.bindEvent($agreement_sign,function(){
            checkNextBtnState();
        },'change');

        //下一步按钮
        appUtils.bindEvent($next, function() {
            if($(this).hasClass('disabled')){
                return;
            }
            submitPhoto();
        });
    }

    /**
     * [showShellUploadOption 显示调用原生壳子的下拉选单]
     */
    function showShellUploadOption(opt){
        LAST_IMG_TYPE = opt.img_type; //标识正反面
        var html_str = ' <div class="overlay select-overlay">\
                           <div class="select-list" data-img-type="'+opt.img_type+'">\
                               <div class="select-item btn-camera">拍照</div>\
                               <div class="select-item btn-album">从相册选择</div>\
                               <div class="select-cancel-btn">取消</div>\
                           </div>\
                        </div>';

        $(_pageId).append(html_str);
        setTimeout(function(){
            $(_pageId+' .select-list').addClass('active');
        },0);

    }

    /**
     * imgState 供原生上传返回调用
     */
    function imgState(data){

        var img_base64 = (data.base64).replace(/[\n\r]*/g,"");

        //身份证正面
        if(LAST_IMG_TYPE==4){

            infoParam.idno       = data.idNo;           // 身份证号
            infoParam.custname   = data.custName;       // 客户姓名
            infoParam.native     = data.native;         // 证件地址
            infoParam.addr       = data.native;         // 联系地址默认为证件地址
            infoParam.ethnicname = data.ethnicName;     // 民族
            infoParam.birthday   = data.birthday;       // 出生日期
            infoParam.gender     = data.userSex;        // 用户性别

            $(_pageId+' #photo-positive-wrap').css({
                'background-image'   :'url('+img_base64+')',
                'background-size'    :'cover',
                'background-position':'center center',
                'background-repeat'  :'no-repeat'
            }).attr('data-uploaded',true);

            checkNextBtnState(); //检测按钮状态
            return;
        }

        //身份证反面
        if(LAST_IMG_TYPE==5){

            infoParam.policeorg   = data.policeOrg;    // 签发机关
            infoParam.idbegindate = data.idbeginDate;  // 证件开始日期
            infoParam.idenddate   = data.idendDate;    // 证件结束日期

            $(_pageId+' #photo-negative-wrap').css({
                'background-image'   :'url('+img_base64+')',
                'background-size'    :'cover',
                'background-position':'center center',
                'background-repeat'  :'no-repeat'
            }).attr('data-uploaded',true);

            checkNextBtnState();//检查按钮状态
            return;
        }
    }


    /**
     * uploadPositive 上传身份证正面
     * @param  {string} dataURL 图片数据base64编码
     * @param  {[type]} tSize   [description]
     * @param  {[type]} file    [description]
     * @param  {[type]} sSize   [description]
     * @param  {[type]} fEvt    [description]
     */
    function uploadPositive(dataURL, tSize, file, sSize, fEvt){

        var img_data = dataURL.split(",")[1];
        var param = {
            "user_id"   : USER_ID, 
            "img_data"  : img_data, 
            "img_type"  : "4", 
            "jsessionid": JSESSIONID
        };

        service.uploadImg(param, function (data) {
            layerUtils.iLoading(false);
            console.log(data);

            if (data.error_no == 0) {

                infoParam.idno       = data.results[0]['idno'];           // 身份证号
                infoParam.custname   = data.results[0]['custname'];       // 客户姓名
                infoParam.native     = data.results[0]['native'];         // 证件地址
                infoParam.addr       = data.results[0]['native'];         // 联系地址默认为证件地址
                infoParam.ethnicname = data.results[0]['ethnicname'];     // 民族
                infoParam.birthday   = data.results[0]['birthday'];       // 出生日期
                infoParam.gender     = data.results[0]['usersex'];        // 用户性别

                $(_pageId+' #photo-positive-wrap').css({
                    'background-image'   :'url('+dataURL+')',
                    'background-size'    :'cover',
                    'background-position':'center center',
                    'background-repeat'  :'no-repeat'
                }).attr('data-uploaded',true);

                checkNextBtnState(); //检测按钮状态
            }else {
                layerUtils.iAlert(data.error_info);
            }
        }, true, false, uploadPhotoTimeOut);
    }

    /**
     * uploadNegative 上传身份证反面
     * @param  {string} dataURL 图片数据base64编码
     * @param  {[type]} tSize   [description]
     * @param  {[type]} file    [description]
     * @param  {[type]} sSize   [description]
     * @param  {[type]} fEvt    [description]
     * @return {[type]}         [description]
     */
    function uploadNegative(dataURL, tSize, file, sSize, fEvt) {
        
        var img_data = dataURL.split(",")[1];

        var param = {
            "user_id"   : USER_ID, 
            "img_data"  : img_data, 
            "img_type"  : "5", 
            "jsessionid": JSESSIONID
        };

        service.uploadImg(param, function (data) {
            layerUtils.iLoading(false);
            console.log(data);

            if (data.error_no == 0) {

                infoParam.policeorg   = data.results[0].policeorg;    // 签发机关
                infoParam.idbegindate = data.results[0].idbegindate;  // 证件开始日期
                infoParam.idenddate   = data.results[0].idenddate;    // 证件结束日期

                $(_pageId+' #photo-negative-wrap').css({
                    'background-image'   :'url('+dataURL+')',
                    'background-size'    :'cover',
                    'background-position':'center center',
                    'background-repeat'  :'no-repeat'
                }).attr('data-uploaded',true);

                checkNextBtnState();//检查按钮状态
            }else{
                layerUtils.iAlert(data.error_info);
            }
        }, true, false, uploadPhotoTimeOut);
    }


    //上传照片超时的回调函数
    function uploadPhotoTimeOut() {
        layerUtils.iAlert("拍照上传超时，请直接从图库选取拍好的照片");
    }

    //检查下一步按钮的状态
    function checkNextBtnState(){

        var $positive  = $(_pageId+' #photo-positive-wrap'),   //  正面
            $negative  = $(_pageId+' #photo-negative-wrap'),   //  反面
            $agreement = $(_pageId+' .agreement-sign'),        //  协议
            $next      = $(_pageId+' .btn-next-step');         // 下一步

        //验证正面
        if($positive.attr('data-uploaded')!=='true'){
            $next.addClass('disabled');
            return;
        }

        //验证反面
        if($negative.attr('data-uploaded')!=='true'){
            $next.addClass('disabled');
            return;
        }

        //验证是否同意协议内容
        if(!$agreement.is(':checked')){
            $next.addClass('disabled');
            return;
        };

        $next.removeClass('disabled');
    }

    /* 清理界面元素
     * 不能写在 destroy 方法里面，写在 destroy 里面，查看协议的时候，界面的元素也会被清理掉
     */
    function cleanPageElement() {

        $(_pageId+' #photo-positive-wrap').attr({
            'data-uploaded':'',
            'style':''
        });

        $(_pageId+' #photo-negative-wrap').attr({
            'data-uploaded':'',
            'style':''
        });
    }


    /**
     * 获取数字证书协议
     * 1.中登证书协议：certprotcl 
     * 2.自建证书协议：zjcertprotcl
     */
    function queryCertAgreement() {
        
        var param = {
            "category_englishname": "certprotcl"
        };

        $(_pageId+' .agreement label a').remove(); //获取协议前线清除已有的内容

        service.queryProtocolList(param, function (data) {

            var $target = $(_pageId+' .agreement label');

            if (data.error_no == 0 && data.results) {
                $.each(data.results, function (index, item) {
                    if (item) {
                        $target.append('<a data-id="'+item.econtract_no+'">《'+item.econtract_name+'》</a>');
                    }
                });
            }
            else {
                layerUtils.iAlert(data.error_info);
            }
        }, true, true, handleTimeout);
    }

    /* 处理请求超时 */
    function handleTimeout() {
        layerUtils.iConfirm("请求超时，是否重新加载？", function () {
            queryCertAgreement();  // 再次获取中登协议
        });
    }


    /**
     * [uploadPhotoByShell 调用shell上传]
     * @param  {[type]} opt [description]
     * @return {[type]}     [description]
     */
    function uploadPhotoByShell(opt){
        var param = {
            "funcNum"    : "501525",
            "uuid"       : "index",
            "r"          : Math.random(),
            "userId"     : USER_ID,
            "photoType"  : "身份证",      // 影像名称
            "action"     : opt.action,   // 照片来源类别，phone-相册，pai-相机
            "imgType"    : opt.img_type,
            "key"        : "index",      // key 和 uuid 只需要写一个
            "url"        : global.serverPath,
            "clientInfo" : CLIENT_INFO, // 从 session 中将 clientinfo 取出
            "jsessionId" : JSESSIONID,  // 从 session 中将 jsessionid 取出
            "funcNo"     : "60002",
            "moduleName" : "open"
        };
        external.callMessage(param);
    }


    /**
     * [uploadPhotoByWeixin 调用微信js-sdk 上传照片]
     * @param  {[type]} opt [对象参数]
     */
    function uploadPhotoByWeixin(opt){

        var param = {
            //为避免与微信SDK接口号冲突，BUS接口号参数名必须为"func_No"
            "func_No"     : "501525",
            "user_id"     : USER_ID,
            "jsessionid"  : JSESSIONID,
            "img_type"    : opt.img_type,
            "count"       : 1,//限制选择多少张照片
            "sizeType"    : ['original', 'compressed'],//压缩类型
            "sourceType"  : ['album', 'camera'],//可以选择相册或拍照，需要升级jweixin.js
            "isNeedCamera": false     //不是必须用相机拍照，可以选择相册。
        };

        //上传到腾讯服务器完成的回调函数
        var uploadComplate = function(data) {
            layerUtils.iLoading(true);

            // 返回选定照片的本地ID列表，localId可以作为img标签的src属性显示图片
            if (data.isNeedCamera && (data.sourceType.indexOf(camera) > -1 && data.sourceType > 0)) {
                layerUtils.iAlert("请使用相机拍摄照片");
                return false;
            } else if (data.localIds.length > 1) {
                layerUtils.iAlert("请仅上传一张图片");
                return false;
            } else if (data.localIds.length == 0) {
                layerUtils.iAlert("请上传一张图片");
                return false;
            }
            
            IMAGES.localId = data.localIds;
            IMAGES.sourceType = data.sourceType;

            return true;
        }


        //下载后调用param.func_No 功能号后的回调函数
        var hasUploadIDCard = function (data) {
            layerUtils.iLoading(false);

            if(data.error_no !== "0"){
                layerUtils.iAlert(data.error_info);
                return;
            }

            //身份证正面
            if(opt.img_type==4){
                infoParam.idno       = data.results[0]['idno'];           // 身份证号
                infoParam.custname   = data.results[0]['custname'];       // 客户姓名
                infoParam.native     = data.results[0]['native'];         // 证件地址
                infoParam.addr       = data.results[0]['native'];         // 联系地址默认为证件地址
                infoParam.ethnicname = data.results[0]['ethnicname'];     // 民族
                infoParam.birthday   = data.results[0]['birthday'];       // 出生日期
                infoParam.gender     = data.results[0]['usersex'];        // 用户性别

                $(_pageId+' #photo-positive-wrap').css({
                    'background-image'   :'url('+IMAGES.localId[0]+')',
                    'background-size'    :'cover',
                    'background-position':'center center',
                    'background-repeat'  :'no-repeat'
                }).attr('data-uploaded',true);

                checkNextBtnState(); //检测按钮状态
                return;
            }

            if(opt.img_type==5){

                infoParam.policeorg   = data.results[0].policeorg;    // 签发机关
                infoParam.idbegindate = data.results[0].idbegindate;  // 证件开始日期
                infoParam.idenddate   = data.results[0].idenddate;    // 证件结束日期

                $(_pageId+' #photo-negative-wrap').css({
                    'background-image'   :'url('+IMAGES.localId[0]+')',
                    'background-size'    :'cover',
                    'background-position':'center center',
                    'background-repeat'  :'no-repeat'
                }).attr('data-uploaded',true);

                checkNextBtnState();//检查按钮状态
                return;
            }
        }

        //上传到腾讯失败的回调函数
        var uploadFail = function(data) {
            layerUtils.iLoading(false);
            if (data.err_no == -1) {
                layerUtils.iAlert("选择图片失败，请重试！");
            }
            layerUtils.iAlert("上传失败,原因：" + JSON.stringify(data));
        };

        utils.uploadPhotoByWeixin(param, uploadComplate, hasUploadIDCard, uploadFail);
    }


    /**
     * [submitPhoto 提交信息]
     *
     *  提交成功后 获取邮政编码 然后跳转到个人信息页面
     *  提交信息成功后需要判断当前的流程状态
     *  1.常规流程 则进入下一步 填写个人信息
     *  2.当前流程为驳回流程 则 走驳回流程
     * 
     */
    function submitPhoto() {

        infoParam.user_id            = USER_ID;
        infoParam.infocolect_channel = iBrowser.pc ? 0 : 3;  //信息来源渠道 0：PC  3：手机
        infoParam.idtype             = "00";
        infoParam.idcardmodify       = "0";
        infoParam.nationality        = "156";
        infoParam.edu                = "";
        infoParam.profession_code    = "";
        infoParam.branchno           = BRANCH_NO;
        infoParam.recommendno        = RECOMMEND_NO;
        infoParam.ipaddr             = IP;
        infoParam.macaddr            = MAC;

        service.submitPhoto(infoParam, function (data) {
            layerUtils.iLoading(false);
            if (data.error_no == 0) {

                var param = {"addr": infoParam.native};
                service.queryPostid(param, function (data) {
                    var error_no = data.error_no;
                    if (data.error_no == 0 && data.results.length != 0) {
                        infoParam.postid = data.results[0]['post'];
                    }
                    appUtils.setSStorageInfo("infoParam", JSON.stringify(infoParam));
                    appUtils.pageInit("account/uploadPhoto", "account/personInfo", {infoParam:infoParam});
                }, false);

            }else{
                layerUtils.iAlert(data.error_info);
            }
        }, false);
    }


    function destroy() {
        service.destroy();
    }


    /* 暴露对外的接口 */
    module.exports = {
        "init"         : init,
        "bindPageEvent": bindPageEvent,
        "pageBack"     : pageBack,
        "imgState"     : imgState,
        "destroy"      : destroy
    };
});